# riptide_cpp
Cross platform 64 bit c++ files for processing numpy arrays with stacking, multifile, and multithreaded SDS file format.

## usage
See examples in https://github.com/rtosholdings/riptable-docdata